@@ -196,15 +196,15 @@ def current_weather_all(
         rain_one_hour = _format_precip(current_weather.rain.one_hour, units)
         rain_three_hour = _format_precip(current_weather.rain.three_hour, units)
     else:
-        rain_one_hour = "0"
-        rain_three_hour = "0"
+        rain_one_hour = "0.00"
+        rain_three_hour = "0.00"
 
     if current_weather.snow:
         snow_one_hour = _format_precip(current_weather.snow.one_hour, units)
         snow_three_hour = _format_precip(current_weather.snow.three_hour, units)
     else:
-        snow_one_hour = "0"
-        snow_three_hour = "0"
+        snow_one_hour = "0.00"
+        snow_three_hour = "0.00"
 
     if current_weather.wind:
         wind = _format_wind(current_weather.wind.speed, units)
@@ -349,7 +349,7 @@ def _format_date_time(
 
 def _format_precip(precip_amount: float | None, units: str) -> str:
     if not precip_amount:
-        return "0"
+        return "0.00"
 
     return str(_mm_to_in(precip_amount)) if units == "imperial" else str(precip_amount)
 
@@ -427,8 +427,8 @@ def hourly_all(
 
     for hourly in weather.hourly:
         dt = _format_date_time(am_pm, hourly.dt, weather.timezone_offset)
-        rain = _format_precip(hourly.rain.one_hour, units) if hourly.rain else "0"
-        snow = _format_precip(hourly.snow.one_hour, units) if hourly.snow else "0"
+        rain = _format_precip(hourly.rain.one_hour, units) if hourly.rain else "0.00"
+        snow = _format_precip(hourly.snow.one_hour, units) if hourly.snow else "0.00"
         wind = _format_wind(hourly.wind_speed, units)
         gusts = _format_wind(hourly.wind_gust, units)
         pressure = _format_pressure(hourly.pressure, units)
